==> istio-model-v1beta1-6.0.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/HTTPFaultInjectionAbortHttp2ErrorFluentImpl.java <==
package io.fabric8.istio.api.networking.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class HTTPFaultInjectionAbortHttp2ErrorFluentImpl<A extends HTTPFaultInjectionAbortHttp2ErrorFluent<A>> extends BaseFluent<A> implements HTTPFaultInjectionAbortHttp2ErrorFluent<A>{
  public HTTPFaultInjectionAbortHttp2ErrorFluentImpl() {
  }
  public HTTPFaultInjectionAbortHttp2ErrorFluentImpl(HTTPFaultInjectionAbortHttp2Error instance) {
    this.withHttp2Error(instance.getHttp2Error()); 
  }
  private String http2Error;
  public String getHttp2Error() {
    return this.http2Error;
  }
  public A withHttp2Error(String http2Error) {
    this.http2Error=http2Error; return (A) this;
  }
  public Boolean hasHttp2Error() {
    return this.http2Error != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    HTTPFaultInjectionAbortHttp2ErrorFluentImpl that = (HTTPFaultInjectionAbortHttp2ErrorFluentImpl) o;
    if (http2Error != null ? !http2Error.equals(that.http2Error) :that.http2Error != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(http2Error,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (http2Error != null) { sb.append("http2Error:"); sb.append(http2Error); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> istio-model-v1beta1-6.7.2-sources.jar: io/fabric8/istio/api/networking/v1beta1/HTTPFaultInjectionAbortHttp2ErrorFluentImpl.java <==
package io.fabric8.istio.api.networking.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class HTTPFaultInjectionAbortHttp2ErrorFluentImpl<A extends HTTPFaultInjectionAbortHttp2ErrorFluent<A>> extends BaseFluent<A> implements HTTPFaultInjectionAbortHttp2ErrorFluent<A>{
  public HTTPFaultInjectionAbortHttp2ErrorFluentImpl() {
  }
  public HTTPFaultInjectionAbortHttp2ErrorFluentImpl(HTTPFaultInjectionAbortHttp2Error instance) {
    if (instance != null) {
      this.withHttp2Error(instance.getHttp2Error());
    }
  }
  private String http2Error;
  public String getHttp2Error() {
    return this.http2Error;
  }
  public A withHttp2Error(String http2Error) {
    this.http2Error=http2Error; return (A) this;
  }
  public Boolean hasHttp2Error() {
    return this.http2Error != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HTTPFaultInjectionAbortHttp2ErrorFluentImpl that = (HTTPFaultInjectionAbortHttp2ErrorFluentImpl) o;
    if (!java.util.Objects.equals(http2Error, that.http2Error)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(http2Error,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (http2Error != null) { sb.append("http2Error:"); sb.append(http2Error); }
    sb.append("}");
    return sb.toString();
  }
  
}
